@@ -1,4 +1,5 @@
 import logging
+import warnings
 from urllib.parse import quote_plus
 
 import requests
@@ -17,7 +18,7 @@ class AlexConfig(dict):
         return super().__setitem__(key, value)
 
 
-config = AlexConfig(email=None, openalex_url="https://api.openalex.org")
+config = AlexConfig(email=None, api_key=None, openalex_url="https://api.openalex.org")
 
 
 def _flatten_kv(k, v):
@@ -85,7 +86,7 @@ class Author(OpenAlexEntity):
     pass
 
 
-class Venue(OpenAlexEntity):
+class Source(OpenAlexEntity):
     pass
 
 
@@ -97,6 +98,24 @@ class Concept(OpenAlexEntity):
     pass
 
 
+class Publisher(OpenAlexEntity):
+    pass
+
+
+# deprecated
+
+def Venue(*args, **kwargs):
+
+    # warn about deprecation
+    warnings.warn(
+        "Venue is deprecated. Use Sources instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+
+    return Source(*args, **kwargs)
+
+
 class CursorPaginator(object):
     def __init__(self, alex_class=None, per_page=None, cursor="*", n_max=None):
 
@@ -147,13 +166,14 @@ class BaseOpenAlex(object):
 
         if key == "groupby":
             raise AttributeError(
-                "Object has no attribute 'groupby'. "
-                "Did you mean 'group_by'?")
+                "Object has no attribute 'groupby'. " "Did you mean 'group_by'?"
+            )
 
         if key == "filter_search":
             raise AttributeError(
                 "Object has no attribute 'filter_search'. "
-                "Did you mean 'search_filter'?")
+                "Did you mean 'search_filter'?"
+            )
 
         return getattr(self, key)
 
@@ -163,9 +183,11 @@ class BaseOpenAlex(object):
             return self._get_multi_items(record_id)
 
         url = self.url + "/" + record_id
-
+        params = {"api_key": config.api_key} if config.api_key else {}
         res = requests.get(
-            url, headers={"User-Agent": "pyalex/" + __version__, "email": config.email}
+            url,
+            headers={"User-Agent": "pyalex/" + __version__, "email": config.email},
+            params=params
         )
         res.raise_for_status()
         res_json = res.json()
@@ -191,17 +213,22 @@ class BaseOpenAlex(object):
                 l.append(k + "=" + quote_plus(str(v)))
 
         url = self.url + "?" + "&".join(l)
-
+        params = {"api_key": config.api_key} if config.api_key else {}
         res = requests.get(
-            url, headers={"User-Agent": "pyalex/" + __version__, "email": config.email}
+            url,
+            headers={"User-Agent": "pyalex/" + __version__, "email": config.email},
+            params=params
         )
-        res_json = res.json()
-
-        if res.status_code == 403 and "query parameters" in res_json["error"]:
-            raise QueryError(res_json["message"])
 
+        # handle query errors
+        if res.status_code == 403:
+            res_json = res.json()
+            if isinstance(res_json["error"], str) and "query parameters" in res_json["error"]:
+                raise QueryError(res_json["message"])
         res.raise_for_status()
 
+        res_json = res.json()
+
         # group-by or results page
         if "group-by" in self.params:
             results = res_json["group_by"]
@@ -299,10 +326,10 @@ class Authors(BaseOpenAlex):
     obj = Author
 
 
-class Venues(BaseOpenAlex):
+class Sources(BaseOpenAlex):
 
-    url = config.openalex_url + "/venues"
-    obj = Venue
+    url = config.openalex_url + "/sources"
+    obj = Source
 
 
 class Institutions(BaseOpenAlex):
@@ -317,6 +344,26 @@ class Concepts(BaseOpenAlex):
     obj = Concept
 
 
+class Publishers(BaseOpenAlex):
+
+    url = config.openalex_url + "/publishers"
+    obj = Publisher
+
+
+# deprecated
+
+def Venues(*args, **kwargs):
+
+    # warn about deprecation
+    warnings.warn(
+        "Venues is deprecated. Use Sources instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+
+    return Sources(*args, **kwargs)
+
+
 # aliases
 People = Authors
-Journals = Venues
+Journals = Sources
