@@ -3,21 +3,27 @@ from pathlib import Path
 
 import pytest
 import requests
+from requests import HTTPError
 
 import pyalex
 from pyalex import Authors
 from pyalex import Concepts
 from pyalex import Institutions
-from pyalex import Venues
+from pyalex import Publishers
+from pyalex import Sources
 from pyalex import Work
 from pyalex import Works
+from pyalex.api import QueryError
 
 
 def test_config():
+    pyalex.config.email = "pyalex_github_unittests@example.com"
 
-    pyalex.config.email = "myemail@example.com"
-
-    assert pyalex.config.email == "myemail@example.com"
+    assert pyalex.config.email == "pyalex_github_unittests@example.com"
+    assert pyalex.config.api_key is None
+    pyalex.config.api_key = "my_api_key"
+    assert pyalex.config.api_key == "my_api_key"
+    pyalex.config.api_key = None
 
 
 def test_meta_entities():
@@ -28,7 +34,7 @@ def test_meta_entities():
     assert "count" in m
     _, m = Institutions().get(return_meta=True)
     assert "count" in m
-    _, m = Venues().get(return_meta=True)
+    _, m = Sources().get(return_meta=True)
     assert "count" in m
     _, m = Works().get(return_meta=True)
     assert "count" in m
@@ -81,6 +87,12 @@ def test_W3128349626_works_no_abstract():
     assert "abstract" not in w
 
 
+def test_work_error():
+
+    with pytest.raises(HTTPError):
+        Works()["NotAWorkID"]
+
+
 def test_random_works():
 
     assert isinstance(Works().random(), dict)
@@ -127,6 +139,12 @@ def test_works_multifilter_meta():
     assert m1["count"] == m2["count"]
 
 
+def test_query_error():
+
+    with pytest.raises(QueryError):
+        Works().filter(publication_year_error=2020).get()
+
+
 def test_data_publications():
 
     w, _ = (
@@ -315,3 +333,8 @@ def test_ngrams_with_metadata():
     r, meta = Works()["W2023271753"].ngrams(return_meta=True)
 
     assert meta["count"] == 1068
+
+
+def test_random_publishers():
+
+    assert isinstance(Publishers().random(), dict)
